/*
 Generic Runtime Library (GRT)
 Copyright (C) 2005 MySQL AB

 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Lesser General Public
 License as published by the Free Software Foundation; either
 version 2.1 of the License, or (at your option) any later version.

 This library is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 Lesser General Public License for more details.

 You should have received a copy of the GNU Lesser General Public
 License along with this library; if not, write to the Free Software
 Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

package com.mysql.grt.base;

public class ObjectEditor extends com.mysql.grt.GrtObject {

    protected ObjectEditor() {
    }

    public ObjectEditor(Object obj) {
        super();

        if ((obj == null) || (obj instanceof com.mysql.grt.GrtObject)) {
            data = new ObjectEditorDataLocal(this);

            data.setOwner((com.mysql.grt.GrtObject) obj);
            com.mysql.grt.Grt.getInstance().addToObjectCache(this);
        } else if (obj instanceof String) {
            data = new ObjectEditorDataGlobal((String) obj);
        }
    }

    public int getRating() {
        return ((ObjectEditorData) data).getRating();
    }

    public int setRating(int rating) {
        ((ObjectEditorData) data).setRating(rating);

        return getRating();
    }

    public int getActionId() {
        return ((ObjectEditorData) data).getActionId();
    }

    public int setActionId(int actionId) {
        ((ObjectEditorData) data).setActionId(actionId);

        return getActionId();
    }

    public String getModuleName() {
        return ((ObjectEditorData) data).getModuleName();
    }

    public String setModuleName(String moduleName) {
        ((ObjectEditorData) data).setModuleName(moduleName);

        return getModuleName();
    }

    public String getModuleFunctionName() {
        return ((ObjectEditorData) data).getModuleFunctionName();
    }

    public String setModuleFunctionName(String moduleFunctionName) {
        ((ObjectEditorData) data).setModuleFunctionName(moduleFunctionName);

        return getModuleFunctionName();
    }

    public String getObjectStructName() {
        return ((ObjectEditorData) data).getObjectStructName();
    }

    public String setObjectStructName(String objectStructName) {
        ((ObjectEditorData) data).setObjectStructName(objectStructName);

        return getObjectStructName();
    }

    public StringBuffer getGrtXmlMembers(StringBuffer xml) {
        super.getGrtXmlMembers(xml);

            xml.append("<value type=\"int\" key=\"rating\">"
                    + Integer.toString(getRating()) + "</value>\n");

            xml.append("<value type=\"int\" key=\"actionId\">"
                    + Integer.toString(getActionId()) + "</value>\n");

            if (getModuleName() != null) {
                xml.append("<value type=\"string\" key=\"moduleName\">"
                        + com.mysql.grt.Grt.escapeStringForXml(getModuleName()) + "</value>\n");
            }

            if (getModuleFunctionName() != null) {
                xml.append("<value type=\"string\" key=\"moduleFunctionName\">"
                        + com.mysql.grt.Grt.escapeStringForXml(getModuleFunctionName()) + "</value>\n");
            }

            if (getObjectStructName() != null) {
                xml.append("<value type=\"string\" key=\"objectStructName\">"
                        + com.mysql.grt.Grt.escapeStringForXml(getObjectStructName()) + "</value>\n");
            }

        return xml;
    }
}
