/*
 Generic Runtime Library (GRT)
 Copyright (C) 2005 MySQL AB

 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Lesser General Public
 License as published by the Free Software Foundation; either
 version 2.1 of the License, or (at your option) any later version.

 This library is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 Lesser General Public License for more details.

 You should have received a copy of the GNU Lesser General Public
 License along with this library; if not, write to the Free Software
 Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

package com.mysql.grt.db.oracle;

public class Column extends com.mysql.grt.db.Column {

    protected Column() {
    }

    public Column(Object obj) {
        super();

        if ((obj == null) || (obj instanceof com.mysql.grt.GrtObject)) {
            data = new ColumnDataLocal(this);

            data.setOwner((com.mysql.grt.GrtObject) obj);
            com.mysql.grt.Grt.getInstance().addToObjectCache(this);
        } else if (obj instanceof String) {
            data = new ColumnDataGlobal((String) obj);
        }
    }

    public int getDefaultLength() {
        return ((ColumnData) data).getDefaultLength();
    }

    public int setDefaultLength(int defaultLength) {
        ((ColumnData) data).setDefaultLength(defaultLength);

        return getDefaultLength();
    }

    public int getNumberOfNulls() {
        return ((ColumnData) data).getNumberOfNulls();
    }

    public int setNumberOfNulls(int numberOfNulls) {
        ((ColumnData) data).setNumberOfNulls(numberOfNulls);

        return getNumberOfNulls();
    }

    public int getNumberOfBuckets() {
        return ((ColumnData) data).getNumberOfBuckets();
    }

    public int setNumberOfBuckets(int numberOfBuckets) {
        ((ColumnData) data).setNumberOfBuckets(numberOfBuckets);

        return getNumberOfBuckets();
    }

    public double getDensity() {
        return ((ColumnData) data).getDensity();
    }

    public double setDensity(double density) {
        ((ColumnData) data).setDensity(density);

        return getDensity();
    }

    public String getDatatypeModifier() {
        return ((ColumnData) data).getDatatypeModifier();
    }

    public String setDatatypeModifier(String datatypeModifier) {
        ((ColumnData) data).setDatatypeModifier(datatypeModifier);

        return getDatatypeModifier();
    }

    public StringBuffer getGrtXmlMembers(StringBuffer xml) {
        super.getGrtXmlMembers(xml);

            xml.append("<value type=\"int\" key=\"defaultLength\">"
                    + Integer.toString(getDefaultLength()) + "</value>\n");

            xml.append("<value type=\"int\" key=\"numberOfNulls\">"
                    + Integer.toString(getNumberOfNulls()) + "</value>\n");

            xml.append("<value type=\"int\" key=\"numberOfBuckets\">"
                    + Integer.toString(getNumberOfBuckets()) + "</value>\n");

            xml.append("<value type=\"real\" key=\"density\">"
                    + Double.toString(getDensity()) + "</value>\n");

            if (getDatatypeModifier() != null) {
                xml.append("<value type=\"string\" key=\"datatypeModifier\">"
                        + com.mysql.grt.Grt.escapeStringForXml(getDatatypeModifier()) + "</value>\n");
            }

        return xml;
    }
}
